import sys
from .classmodule import MyClass
from .funcmodule import set_up, existing_data

def main():
    if not (sys.version_info.major == 3 and sys.version_info.minor >= 5):
        print("This script requires Python 3.5 or higher!")
        print("You are using Python {}.{}.".format(sys.version_info.major, sys.version_info.minor))
        sys.exit(1)
    args = sys.argv
    args.append('')
    if(args[1].lower()=='start'):
        while True:
            cID = input("Enter client id = ")
            if not cID.isdigit():
                print("Client Id can only be integer = ")
            else:
                break
        activity = set_up(cID)
        activity["clientId"]=cID
        richPresence(activity)
    elif(args[1].lower()=='autostart'):
        activity = existing_data()
        richPresence(activity)
    else:
    	print("""
    	              Discord Rich Presence
    	===================================================
    	start     : Starts an ineractive setup to start RPC
    	===================================================
    	autostart : AutoStarts RPC from database
    	""")

def richPresence(activity):
    ob = MyClass(activity['clientId'])
    b = ob.connect()
    if b:
        ob.statusUpdate(activity)
        while True:
            x = input()
            if x.lower()=="update":
                activity = set_up(activity['clientId'])
                ob.statusUpdate(activity)
            elif x.lower()=='end':
                ob.close_presence()
                break
            else:
                print("""
               Discord Rich Presence After Start Up
        ===================================================
        updates : Starts an ineractive setup to update RPC
        ===================================================
        end   : closes RPC server
    """)

if __name__ == '__main__':
    main()


from pypresence import Presence
import os

class MyClass():
    def __init__(self, client_id):
    	self.client_id = client_id
    	self.RPC = Presence(self.client_id)

    def connect(self):
    	try:
            self.RPC.connect()
            return True
    	except Exception as e:
            print(str(e))
            return False

    def statusUpdate(self, state):
        try:
            self.RPC.update(details=state['details'],state=state["state"],start=state["startTimestamp"],large_image=state['largeImageKey'], large_text=state["largeImageText"],small_image=state['smallImageKey'], small_text=state["smallImageKey"], buttons=state["buttons"])
        except Exception as e:
            print(str(e))

    def close_presence(self):
        try:
            self.RPC.clear(pid=os.getpid())
        except Exception as e:
            print(str(e))



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="pyrpc-discord",
    version="1.1.2",
    python_requires='>=3.5',
    description="A Small Project To Automate Discord Rich Presence using CLI",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/bartick/pyrpc-discord",
    author="Bartick Maiti",
    platforms=['Windows', 'Linux', 'OSX'],
    author_email="blackmumba890@gmail.com",
    license="MIT",
    classifiers=[
    	"Framework :: AsyncIO",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["pyrpc"],
    include_package_data=True,
    install_requires=[
    	"pypresence>=4.2.0"
    ],
    entry_points={
        "console_scripts": [
            "pyrpc=pyrpc.__main__:main",
        ]
    },
)


import time
import sqlite3

def set_up(cID):
	activity = {"startTimestamp":time.time()}
	activityKey = ["details", "state", "largeImageKey", "largeImageText", "smallImageKey", "smallImageText"]

	for i in activityKey:
		answer = input(f"Enter {i} = ")
		activity[i]=answer if not answer=='' else None

	button = input("Do you want set a button (yes/no) = ")
	if button.lower()=='yes' or button.lower()=='y':
		activity["buttons"]=[]
		for i in range(2):
			nums = ['st','nd']
			while True:
				label = input(f"Enter the LABEL for {i+1}{nums[i]} button = ")
				if label=='':
					print("LABEL cannot be empty please input again. ")
				else:
					break
			while True:
				buttonLink = input(f"Enter the URL for {i+1}{nums[i]} button = ")
				if label=='':
					print("URL cannot be empty please input again. ")
				else:
					break
			newButton = {"label":label,"url":buttonLink}
			activity["buttons"].append(newButton)
			if i==0:
				button = input("Do you want a second button? (yes/no) = ")
				if button.lower()=='yes' or button.lower()=='y':
					continue
				else:
					break

		if len(activity['buttons'])==0:
			activity['buttons']=None
	else:
		activity['buttons']=None
	save_data(activity, cID)

	return activity

def save_data(activity, cID):
	con = sqlite3.connect('database.db')
	c = con.cursor()
	select = c.execute('''SELECT name FROM sqlite_master WHERE type='table' AND name="discord"''')
	if len(select.fetchall())==0:
		c.execute('''CREATE TABLE discord(id INT, clientid INT,details TEXT, state TEXT, largeImageKey TEXT, largeImageText TEXT, smallImageKey TEXT, smallImageText TEXT, btlbl1 TEXT, bturl1 TEXT, btlbl2 TEXT, bturl2 TEXT)''')
		con.commit()
	if activity['buttons']==None:
		activity['btlbl1']=""
		activity['bturl1']=""
		activity['btlbl2']=""
		activity['bturl2']=""
	else:
		if(len(activity)==1):
			activity['btlbl1']=activity['buttons'][0]['label']
			activity['bturl1']=activity['buttons'][0]['url']
			activity['btlbl2']=""
			activity['bturl2']=""
		else:
			activity['btlbl1']=activity['buttons'][0]['label']
			activity['bturl1']=activity['buttons'][0]['url']
			activity['btlbl2']=activity['buttons'][1]['label']
			activity['bturl2']=activity['buttons'][1]['url']

	task = (cID, activity['details'], activity['state'],activity['largeImageKey'],activity['largeImageText'],activity['smallImageKey'],activity['smallImageText'],activity['btlbl1'],activity['bturl1'],activity['btlbl2'],activity['bturl2'])
	select = c.execute('''SELECT id FROM discord WHERE id=1''').fetchone()
	if select==None:
		sql = '''INSERT INTO discord(id,clientid,details,state,largeImageKey,largeImageText,smallImageKey,smallImageText,btlbl1,bturl1,btlbl2,bturl2) VALUES(1, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)'''
	else:
		sql = '''UPDATE discord SET clientid=?, details=?, state=?, largeImageKey=?, largeImageText=?, smallImageKey=?, smallImageText=?, btlbl1=?, bturl1=?, btlbl2=?, bturl2=?'''
	c.execute(sql,task)
	con.commit()
	con.close()

def storage():
	con = sqlite3.connect('database.db')
	c = con.cursor()
	select = c.execute('''SELECT name FROM sqlite_master WHERE type='table' AND name="discord"''')
	if len(select.fetchall())==0:
		c.execute('''CREATE TABLE discord(id INT, clientid INT,details TEXT, state TEXT, largeImageKey TEXT, largeImageText TEXT, smallImageKey TEXT, smallImageText TEXT, btlbl1 TEXT, bturl1 TEXT, btlbl2 TEXT, bturl2 TEXT)''')
		con.commit()
	select = c.execute('''SELECT * FROM discord WHERE id=1''').fetchone()
	if select==None:
		while True:
			cID = input("Enter client id = ")
			if not cID.isdigit():
				print("Client Id can only be integer = ")
			else:
				break
		c.execute('''INSERT INTO discord(id,clientid,details,state,largeImageKey,largeImageText,smallImageKey,smallImageText,btlbl1,bturl1,btlbl2,bturl2) VALUES(1,?,"","","","","","","","","","")''',(cID,))
		con.commit()
		select = (1,cID,"","","","","","","","","")
	con.close()
	return select

def existing_data():
	select = storage()
	activity = {"startTimestamp":time.time()}
	activityKey = ["clientId","details", "state", "largeImageKey", "largeImageText", "smallImageKey", "smallImageText"]
	for i in range(6):
		activity[activityKey[i]] = select[i+1] if not select[i+1]=="" else None
	if select[7]=="":
		activity['buttons']=None
	else:
		activity['buttons']=[]
		newButton = {"label":select[8],"url":select[9]}
		activity['buttons'].append(newButton)
		if not select[9]=="":
			newButton = {"label":select[10],"url":select[11]}
			activity['buttons'].append(newButton)
	return activity
